@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-import dataclasses
-
 from conans import ConanFile, tools
 from conans.model import Generator
 from conans.errors import ConanInvalidConfiguration, ConanException
@@ -11,7 +9,8 @@ import json
 import subprocess
 import re
 
-required_conan_version = ">=1.43"
+
+required_conan_version = ">=1.43 <=1.62"
 
 
 def _sanitize_path(path: str):
@@ -26,11 +25,11 @@ class ToolchainDiscoveryError(RuntimeError):
     pass
 
 
-@dataclasses.dataclass
 class SemVer:
-    major: int = 0
-    minor: int = 0
-    patch: int = 0
+    def __init__(self, major: int, minor: int, patch: int):
+        self.major = major
+        self.minor = minor
+        self.patch = patch
 
     def __str__(self):
         return f"{self.major}.{self.minor}.{self.patch}"
@@ -340,5 +339,5 @@ class RapidGenerator(Generator):
 
 class Pkg(ConanFile):
     name = "rapidbuild"
-    version = "0.1"
+    version = "0.5.1"
     license = "MIT"
